import { ApolloQueryResult } from "@apollo/client/core";
import type { CustomHeaders, Query } from "@vue-storefront/magento-types";
import { CustomQuery, QueryCategoriesArgs } from "@vue-storefront/magento-types";
import { Context } from "../../types/context";
export type CategoriesQuery = Required<Pick<Query, "categories">>;
/**
 * Fetch list of all categories matching specified filters
 *
 * @example
 * Simple usage:
 * ```ts
 * import { sdk } from '~/sdk.config.ts';
 *
 * // fetch list of categories with default parameters
 * const categories = await sdk.magento.categories({});
 * ```
 *
 * @example
 * Creating a custom GraphQL query for fetching categories.
 *
 * ```ts
 * module.exports = {
 *   integrations: {
 *     magento: {
 *       customQueries: {
 *         'categories-custom-query': ({ variables, metadata }) => ({
 *            variables,
 *            query: `
 *              query categories {
 *                 categories {
 *                   ${metadata.fields}
 *                 }
 *               }
 *            `
 *         }),
 *       },
 *     }
 *   }
 * };
 * ```
 *
 * @example
 * Using a custom GraphQL query to fetch categories.
 *
 * ```ts
 * import { sdk } from '~/sdk.config.ts';
 * const customQuery = {
 *  categories: 'categories-custom-query',
 *    metadata: {
 *      fields: 'items { uid name }'
 *    }
 * };
 *
 * const categories = await sdk.magento.categories({}, customQuery);
 *
 * // Category list will contain only the fields specified in the custom query.
 * ```
 */
export declare function categories(context: Context, params: QueryCategoriesArgs, customQuery?: CustomQuery, customHeaders?: CustomHeaders): Promise<ApolloQueryResult<CategoriesQuery>>;
//# sourceMappingURL=index.d.ts.map